=============
HIgh Resolution Energy demand model (HIRE)
=============

This is the full documentation of HIRE.

HIRE was written in Python (Python>=3.6) and developed
at the Environmental Change Institute, University of Oxford
within the EPSRC sponsored MISTRAL programme,
as part of the Infrastructure Transition
Research Consortium.


Contents
========

.. toctree::
   :maxdepth: 4

   Documentation <documentation>
   Modelling code <api/modules>
   Authors <authors>
   Versions <changes>
   License <license>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
